@@ -17,6 +17,8 @@ logging.basicConfig()
 logger = logging.getLogger(__name__)
 
 # Enums
+
+
 class UpdateTypeEnum(str, Enum):
     NEW_MESSAGE = "NewMessage"
     UPDATED_MESSAGE = "UpdatedMessage"
@@ -25,11 +27,13 @@ class UpdateTypeEnum(str, Enum):
     STOPPED_BOT = "StoppedBot"
     UPDATED_PAYMENT = "UpdatedPayment"
 
+
 class ChatKeypadTypeEnum(str, Enum):
     NONE = "None"
     NEW = "New"
     REMOVE = "Remove"
 
+
 class ButtonTypeEnum(str, Enum):
     SIMPLE = "Simple"
     SELECTION = "Selection"
@@ -54,6 +58,8 @@ class ButtonTypeEnum(str, Enum):
     BARCODE = "Barcode"
 
 # Data Models
+
+
 @dataclass
 class Button:
     id: str
@@ -66,20 +72,24 @@ class Button:
     button_location: Optional[Dict] = None
     button_textbox: Optional[Dict] = None
 
+
 @dataclass
 class KeypadRow:
     buttons: List[Button]
 
+
 @dataclass
 class MessageId:
     message_id: Optional[str] = None
 
+
 @dataclass
 class Keypad:
     rows: List[KeypadRow]
     resize_keyboard: bool = True
     on_time_keyboard: bool = False
 
+
 @dataclass
 class Message:
     message_id: str
@@ -98,6 +108,7 @@ class Message:
     poll: Optional[Dict] = None
     live_location: Optional[Dict] = None
 
+
 @dataclass
 class Update:
     type: UpdateTypeEnum
@@ -129,6 +140,7 @@ class Update:
             chat_keypad_type=chat_keypad_type
         )
 
+
 @dataclass
 class InlineMessage:
     sender_id: str
@@ -140,10 +152,13 @@ class InlineMessage:
     aux_data: Optional[Dict] = None
 
 # Filters
+
+
 class Filter:
     async def check(self, update: Union[Update, InlineMessage]) -> bool:
         return True
 
+
 class TextFilter(Filter):
     def __init__(self, text: str, regex: bool = False):
         self.text = text
@@ -151,58 +166,83 @@ class TextFilter(Filter):
 
     async def check(self, update: Union[Update, InlineMessage]) -> bool:
         import re
-        text = update.new_message.text if isinstance(update, Update) and update.new_message else update.text if isinstance(update, InlineMessage) else ""
+        text = update.new_message.text if isinstance(
+            update, Update) and update.new_message else update.text if isinstance(
+            update, InlineMessage) else ""
         if not text:
             return False
-        return bool(re.match(self.text, text)) if self.regex else text == self.text
+        return bool(
+            re.match(
+                self.text,
+                text)) if self.regex else text == self.text
+
 
 class CommandFilter(Filter):
     def __init__(self, command: Union[str, List[str]]):
         self.commands = [command] if isinstance(command, str) else command
 
     async def check(self, update: Union[Update, InlineMessage]) -> bool:
-        text = update.new_message.text if isinstance(update, Update) and update.new_message else update.text if isinstance(update, InlineMessage) else ""
+        text = update.new_message.text if isinstance(
+            update, Update) and update.new_message else update.text if isinstance(
+            update, InlineMessage) else ""
         if not text:
             return False
         return any(text.startswith(f"/{cmd}") for cmd in self.commands)
 
+
 class ButtonFilter(Filter):
     def __init__(self, button_id: str):
         self.button_id = button_id
 
     async def check(self, update: Union[Update, InlineMessage]) -> bool:
         aux_data = None
-        update_type = "InlineMessage" if isinstance(update, InlineMessage) else update.type
-        if isinstance(update, Update) and (update.new_message or update.updated_message):
+        update_type = "InlineMessage" if isinstance(
+            update, InlineMessage) else update.type
+        if isinstance(
+                update, Update) and (
+                update.new_message or update.updated_message):
             message = update.new_message or update.updated_message
             aux_data = message.aux_data
         elif isinstance(update, InlineMessage):
             aux_data = update.aux_data
 
         if not aux_data:
-            logger.info(f"No aux_data for button_id={self.button_id} in {update_type}")
+            logger.info(
+                f"No aux_data for button_id={self.button_id} in {update_type}")
             return False
 
-        button_id = aux_data.get("button_id") or aux_data.get("callback_data") or ""
+        button_id = aux_data.get("button_id") or aux_data.get(
+            "callback_data") or ""
         result = button_id == self.button_id
-        logger.info(f"ButtonFilter check for button_id={self.button_id} in {update_type}: {result}, aux_data={aux_data}")
+        logger.info(
+            f"ButtonFilter check for button_id={self.button_id} in {update_type}: {result}, aux_data={aux_data}")
         return result
 
+
 class UpdateTypeFilter(Filter):
     def __init__(self, update_types: Union[str, List[str]]):
-        self.update_types = [update_types] if isinstance(update_types, str) else update_types
+        self.update_types = [update_types] if isinstance(
+            update_types, str) else update_types
 
     async def check(self, update: Union[Update, InlineMessage]) -> bool:
-        result = (isinstance(update, Update) and update.type in self.update_types) or \
-                 (isinstance(update, InlineMessage) and "InlineMessage" in self.update_types)
-        logger.info(f"UpdateTypeFilter check for types={self.update_types}, update={type(update).__name__}: {result}")
+        result = (isinstance(update, Update) and update.type in self.update_types) or (
+            isinstance(update, InlineMessage) and "InlineMessage" in self.update_types)
+        logger.info(
+            f"UpdateTypeFilter check for types={self.update_types}, update={type(update).__name__}: {result}")
         return result
 
+
 class BotClient:
-    def __init__(self, token: str, state_file: str = "bot_state.json", rate_limit: float = 0.5, use_webhook: bool = False):
+    def __init__(
+            self,
+            token: str,
+            state_file: str = "bot_state.json",
+            rate_limit: float = 0.5,
+            use_webhook: bool = False):
         self.token = token
         self.base_url = f"https://botapi.rubika.ir/v3/{token}/"
-        self.handlers: Dict[str, List[Tuple[Tuple[Filter, ...], Callable]]] = {}
+        self.handlers: Dict[str,
+                            List[Tuple[Tuple[Filter, ...], Callable]]] = {}
         self.session = None
         self.running = False
         self.next_offset_id = None
@@ -220,8 +260,11 @@ class BotClient:
             with open(self.state_file, "r") as f:
                 state = json.load(f)
                 self.next_offset_id = state.get("next_offset_id")
-                self.processed_messages = deque(state.get("processed_messages", []), maxlen=10000)
-                logger.info(f"Loaded state: next_offset_id={self.next_offset_id}")
+                self.processed_messages = deque(
+                    state.get("processed_messages", []),
+                    maxlen=10000)
+                logger.info(
+                    f"Loaded state: next_offset_id={self.next_offset_id}")
         except Exception as e:
             logger.error(f"Failed to load state: {str(e)}")
 
@@ -267,8 +310,11 @@ class BotClient:
             async with self.session.post(url, json=data) as response:
                 if response.status != 200:
                     text = await response.text()
-                    logger.error(f"Request failed: {method} status={response.status} body={text}")
-                    raise aiohttp.ClientResponseError(response.request_info, response.history, status=response.status, message=text)
+                    logger.error(
+                        f"Request failed: {method} status={response.status} body={text}")
+                    raise aiohttp.ClientResponseError(
+                        response.request_info, response.history,
+                        status=response.status, message=text)
                 result = await response.json()
                 logger.debug(f"API response for {method}: {result}")
                 return result
@@ -307,16 +353,20 @@ class BotClient:
             data["reply_to_message_id"] = str(reply_to_message_id)
         try:
             response = await self._make_request("sendMessage", data)
-            if response.get("status") == "OK" and "data" in response and "message_id" in response["data"]:
-                self.processed_messages.append(str(response["data"]["message_id"]))
+            if response.get(
+                    "status") == "OK" and "data" in response and "message_id" in response["data"]:
+                self.processed_messages.append(
+                    str(response["data"]["message_id"]))
                 if not self.use_webhook:
                     self._save_state()
-                logger.info(f"Message sent successfully to chat_id={chat_id}, message_id={response['data']['message_id']}")
+                logger.info(
+                    f"Message sent successfully to chat_id={chat_id}, message_id={response['data']['message_id']}")
             else:
                 logger.error(f"Failed to send message: {response}")
             return response
         except Exception as e:
-            logger.error(f"Error sending message to chat_id={chat_id}: {str(e)}")
+            logger.error(
+                f"Error sending message to chat_id={chat_id}: {str(e)}")
             return {"status": "ERROR", "error": str(e)}
 
     async def send_message_with_buttons(
@@ -331,23 +381,26 @@ class BotClient:
                 rows=[
                     KeypadRow(
                         buttons=[
-                            Button(id=btn["id"], type=ButtonTypeEnum.SIMPLE, button_text=btn["text"])
-                            for btn in row
-                        ]
-                    )
-                    for row in buttons
-                ]
-            )
+                            Button(
+                                id=btn["id"],
+                                type=ButtonTypeEnum.SIMPLE,
+                                button_text=btn["text"])
+                            for btn in row]) for row in buttons])
         return await self.send_message(chat_id, text, inline_keypad=inline_keypad)
 
-    async def send_poll(self, chat_id: str, question: str, options: List[str]) -> Dict:
+    async def send_poll(
+            self,
+            chat_id: str,
+            question: str,
+            options: List[str]) -> Dict:
         data = {
             "chat_id": chat_id,
             "question": question,
             "options": options
         }
         response = await self._make_request("sendPoll", data)
-        if response.get("status") == "OK" and "data" in response and "message_id" in response["data"]:
+        if response.get(
+                "status") == "OK" and "data" in response and "message_id" in response["data"]:
             self.processed_messages.append(str(response["data"]["message_id"]))
             if not self.use_webhook:
                 self._save_state()
@@ -378,7 +431,8 @@ class BotClient:
         if reply_to_message_id:
             data["reply_to_message_id"] = str(reply_to_message_id)
         response = await self._make_request("sendLocation", data)
-        if response.get("status") == "OK" and "data" in response and "message_id" in response["data"]:
+        if response.get(
+                "status") == "OK" and "data" in response and "message_id" in response["data"]:
             self.processed_messages.append(str(response["data"]["message_id"]))
             if not self.use_webhook:
                 self._save_state()
@@ -411,7 +465,8 @@ class BotClient:
         if reply_to_message_id:
             data["reply_to_message_id"] = str(reply_to_message_id)
         response = await self._make_request("sendContact", data)
-        if response.get("status") == "OK" and "data" in response and "message_id" in response["data"]:
+        if response.get(
+                "status") == "OK" and "data" in response and "message_id" in response["data"]:
             self.processed_messages.append(str(response["data"]["message_id"]))
             if not self.use_webhook:
                 self._save_state()
@@ -424,7 +479,10 @@ class BotClient:
             return {}
         return response.get("data", {})
 
-    async def get_updates(self, limit: int = 100, offset_id: str = "") -> List[Union[Update, InlineMessage]]:
+    async def get_updates(self,
+                          limit: int = 100,
+                          offset_id: str = "") -> List[Union[Update,
+                                                             InlineMessage]]:
         data = {"limit": limit}
         if offset_id or self.next_offset_id:
             data["offset_id"] = self.next_offset_id if not offset_id else offset_id
@@ -435,7 +493,8 @@ class BotClient:
                 update = self._parse_update(item)
                 if update:
                     updates.append(update)
-            self.next_offset_id = response.get("data", {}).get("next_offset_id")
+            self.next_offset_id = response.get(
+                "data", {}).get("next_offset_id")
             if not self.use_webhook:
                 self._save_state()
         except Exception as e:
@@ -456,13 +515,19 @@ class BotClient:
             "disable_notification": disable_notification
         }
         response = await self._make_request("forwardMessage", data)
-        if response.get("status") == "OK" and "data" in response and "new_message_id" in response["data"]:
-            self.processed_messages.append(str(response["data"]["new_message_id"]))
+        if response.get(
+                "status") == "OK" and "data" in response and "new_message_id" in response["data"]:
+            self.processed_messages.append(
+                str(response["data"]["new_message_id"]))
             if not self.use_webhook:
                 self._save_state()
         return response
 
-    async def edit_message_text(self, chat_id: str, message_id: str, text: str) -> Dict:
+    async def edit_message_text(
+            self,
+            chat_id: str,
+            message_id: str,
+            text: str) -> Dict:
         data = {
             "chat_id": chat_id,
             "message_id": str(message_id),
@@ -518,11 +583,13 @@ class BotClient:
             if filter_key not in self.handlers:
                 self.handlers[filter_key] = []
             self.handlers[filter_key].append((filters, handler))
-            logger.info(f"Registered handler {handler.__name__} with filters: {filters}")
+            logger.info(
+                f"Registered handler {handler.__name__} with filters: {filters}")
             return handler
         return decorator
 
-    def _parse_update(self, item: Dict) -> Optional[Union[Update, InlineMessage]]:
+    def _parse_update(
+            self, item: Dict) -> Optional[Union[Update, InlineMessage]]:
         update_type = item.get("type")
         if not update_type:
             logger.debug(f"Skipping update with no type: {item}")
@@ -540,21 +607,22 @@ class BotClient:
             msg_key = "new_message" if update_type == UpdateTypeEnum.NEW_MESSAGE else "updated_message"
             msg_data = item.get(msg_key)
             if not msg_data:
-                logger.debug(f"Skipping {msg_key} with no message data: {item}")
+                logger.debug(
+                    f"Skipping {msg_key} with no message data: {item}")
                 return None
 
             msg_data["message_id"] = str(msg_data.get("message_id", ""))
             try:
                 message_obj = Message(**msg_data)
                 return Update(
-                    client=self,
-                    type=update_type,
-                    chat_id=chat_id,
-                    new_message=message_obj if update_type == UpdateTypeEnum.NEW_MESSAGE else None,
-                    updated_message=message_obj if update_type == UpdateTypeEnum.UPDATED_MESSAGE else None
-                )
+                    client=self, type=update_type, chat_id=chat_id,
+                    new_message=message_obj
+                    if update_type == UpdateTypeEnum.NEW_MESSAGE else None,
+                    updated_message=message_obj
+                    if update_type == UpdateTypeEnum.UPDATED_MESSAGE else None)
             except Exception as e:
-                logger.error(f"Failed to parse message: {msg_data}, error: {str(e)}")
+                logger.error(
+                    f"Failed to parse message: {msg_data}, error: {str(e)}")
                 return None
         elif update_type == "InlineMessage":
             try:
@@ -570,19 +638,25 @@ class BotClient:
                 logger.info(f"Parsed InlineMessage: {inline_msg}")
                 return inline_msg
             except Exception as e:
-                logger.error(f"Failed to parse InlineMessage: {item}, error: {str(e)}")
+                logger.error(
+                    f"Failed to parse InlineMessage: {item}, error: {str(e)}")
                 return None
         else:
             logger.debug(f"Unhandled update type: {update_type}, data: {item}")
             return None
 
     async def process_update(self, update: Union[Update, InlineMessage]):
-        update_type = "InlineMessage" if isinstance(update, InlineMessage) else update.type
+        update_type = "InlineMessage" if isinstance(
+            update, InlineMessage) else update.type
         message_id = self._extract_message_id(update)
 
-        # Skip processed messages check for InlineMessage to avoid issues with repeated message_id
-        if isinstance(update, Update) and message_id and message_id in self.processed_messages:
-            logger.debug(f"Skipping processed update ({update_type}): {message_id}")
+        # Skip processed messages check for InlineMessage to avoid issues with
+        # repeated message_id
+        if isinstance(
+                update,
+                Update) and message_id and message_id in self.processed_messages:
+            logger.debug(
+                f"Skipping processed update ({update_type}): {message_id}")
             return
 
         if message_id and isinstance(update, Update):
@@ -595,15 +669,18 @@ class BotClient:
             for filters, handler in handler_list:
                 if await self._filters_pass(update, filters):
                     try:
-                        logger.info(f"Executing handler {handler.__name__} for update {update_type}")
+                        logger.info(
+                            f"Executing handler {handler.__name__} for update {update_type}")
                         await handler(self, update)
                         handled = True
                     except Exception as e:
-                        logger.exception(f"Error in handler {handler.__name__}: {str(e)}")
+                        logger.exception(
+                            f"Error in handler {handler.__name__}: {str(e)}")
                 else:
                     pass
 
-    def _extract_message_id(self, update: Union[Update, InlineMessage]) -> Optional[str]:
+    def _extract_message_id(
+            self, update: Union[Update, InlineMessage]) -> Optional[str]:
         if isinstance(update, InlineMessage):
             return update.message_id
         if isinstance(update, Update):
@@ -615,8 +692,11 @@ class BotClient:
                 return update.updated_message.message_id
         return None
 
-    async def _filters_pass(self, update: Union[Update, InlineMessage], filters: Tuple[Filter, ...]) -> bool:
-        update_type = "InlineMessage" if isinstance(update, InlineMessage) else update.type
+    async def _filters_pass(
+            self, update: Union[Update, InlineMessage],
+            filters: Tuple[Filter, ...]) -> bool:
+        update_type = "InlineMessage" if isinstance(
+            update, InlineMessage) else update.type
         for f in filters:
             result = await f.check(update)
             if not result:
@@ -630,25 +710,27 @@ class BotClient:
 
         try:
             data = await request.json()
-            logger.debug(f"Webhook payload for {request.path}: {json.dumps(data, ensure_ascii=False)}")
+            logger.debug(
+                f"Webhook payload for {request.path}: {json.dumps(data, ensure_ascii=False)}")
             updates = []
 
             # Handle inline_message
             if "inline_message" in data:
                 try:
                     inline_msg = InlineMessage(
-                        sender_id=data["inline_message"].get("sender_id", ""),
+                        sender_id=data["inline_message"].get(
+                            "sender_id", ""),
                         text=data["inline_message"].get("text", ""),
-                        message_id=str(data["inline_message"].get("message_id", "")),
+                        message_id=str(
+                            data["inline_message"].get("message_id", "")),
                         chat_id=data["inline_message"].get("chat_id", ""),
                         file=data["inline_message"].get("file"),
                         location=data["inline_message"].get("location"),
-                        aux_data=data["inline_message"].get("aux_data")
-                    )
+                        aux_data=data["inline_message"].get("aux_data"))
                     updates.append(inline_msg)
                 except Exception as e:
                     logger.error(f"Failed to parse InlineMessage: {str(e)}")
-            
+
             # Handle updates
             elif "update" in data:
                 update = self._parse_update(data["update"])
@@ -661,21 +743,34 @@ class BotClient:
             return web.json_response({"status": "OK"})
         except json.JSONDecodeError:
             logger.error("Invalid JSON in webhook request")
-            return web.json_response({"status": "ERROR", "error": "Invalid JSON"}, status=400)
+            return web.json_response(
+                {"status": "ERROR", "error": "Invalid JSON"},
+                status=400)
         except Exception as e:
             logger.error(f"Webhook error for {request.path}: {str(e)}")
-            return web.json_response({"status": "ERROR", "error": str(e)}, status=500)
+            return web.json_response(
+                {"status": "ERROR", "error": str(e)},
+                status=500)
 
-    async def run(self, webhook_url: Optional[str] = None, path: Optional[str] = '/webhook', host: str = "0.0.0.0", port: int = 8080):
+    async def run(
+            self,
+            webhook_url: Optional[str] = None,
+            path: Optional[str] = '/webhook',
+            host: str = "0.0.0.0",
+            port: int = 8080):
         self.use_webhook = bool(webhook_url)
         await self.start()
         if self.use_webhook:
             app = web.Application()
             webhook_base = path.rstrip('/')
             app.router.add_post(f"{webhook_base}", self.handle_webhook)
-            app.router.add_post(f"{webhook_base}/receiveUpdate", self.handle_webhook)
-            app.router.add_post(f"{webhook_base}/receiveInlineMessage", self.handle_webhook)
-            
+            app.router.add_post(
+                f"{webhook_base}/receiveUpdate",
+                self.handle_webhook)
+            app.router.add_post(
+                f"{webhook_base}/receiveInlineMessage",
+                self.handle_webhook)
+
             webhook_url = f"{webhook_url.rstrip('/')}{webhook_base}"
             for endpoint_type in ["ReceiveUpdate", "ReceiveInlineMessage"]:
                 response = await self.update_bot_endpoints(webhook_url, endpoint_type)
@@ -698,4 +793,4 @@ class BotClient:
                     await asyncio.sleep(1)
                 except Exception as error:
                     logger.error(f"Polling error: {str(error)}")
-                    await asyncio.sleep(5)
\ No newline at end of file
+                    await asyncio.sleep(5)
