@@ -84,7 +84,7 @@ class Update:
         return self.find_keys('message')
 
     @property
-    def is_me(self):
+    def me(self):
         return self.author_guid == self.client.guid
 
     @property
@@ -109,7 +109,7 @@ class Update:
         return self.find_keys('title')
 
     @property
-    def is_forward(self) -> bool:
+    def forward(self) -> bool:
         message = self.message
         return message is not None and 'forwarded_from' in message.original_update
 
@@ -118,7 +118,7 @@ class Update:
         return self.find_keys('forwarded_from').type_from
 
     @property
-    def is_event(self) -> bool:
+    def event(self) -> bool:
         return self.message is not None and self.message.type == 'Event'
 
     @property
@@ -188,15 +188,15 @@ class Update:
         return self.message.find_keys(keys='reply_to_message_id')
 
     @property
-    def is_group(self):
+    def group(self):
         return self.type == 'Group'
 
     @property
-    def is_channel(self):
+    def channel(self):
         return self.type == 'Channel'
 
     @property
-    def is_private(self):
+    def private(self):
         return self.type == 'User'
 
     @property
